@@ -24,5 +24,20 @@ class NotFoundChromeError(ErrorBase):
     未找到chrome浏览器
     """
 
-    def __init__(self, message="🚨 未找到chrome浏览器"):
+    def __init__(self, message="🚨 未找到chrome浏览器，请手动下载或指定 browser_path 参数"):
         super().__init__(message)
+
+
+class ChromeDownloadError(Exception):
+    """Chrome下载相关错误"""
+    pass
+
+
+class ChromePermissionError(Exception):
+    """Chrome权限相关错误"""
+    pass
+
+
+class ChromePathError(Exception):
+    """Chrome路径相关错误"""
+    pass
